@@ -26,7 +26,7 @@ if($n == 1){
         print("#!ipxe
 
 # Boot the first local HDD
-sanboot --no-describe --drive 0x80
+sanboot --no-describe --drive 0x80 || sanboot --no-describe --drive 0x81
 ");
         break;
     case "bootinglive":
